/**
 * Created by user on 2018/5/6/006.
 */
import { ICreateRegExp, ITypeCreateRegExp } from '../../index';
import { IPatternTestRow } from '../../pattern';
export declare const KEY_PREFIX = "\\p{Script=";
export declare const KEY_PREFIX_NEGATION = "\\P{Script=";
export declare const KEY_SUFFIX = "}";
/**
 * @link http://2ality.com/2017/07/regexp-unicode-property-escapes.html
 * @link https://en.wikipedia.org/wiki/Unicode_character_property
 */
export declare const UNICODE_SCRIPTS: {
    Greek: boolean;
    Latin: boolean;
};
export declare const UNICODE_SCRIPTS_ALL: {
    "Adlam": boolean;
    "Ahom": boolean;
    "Anatolian_Hieroglyphs": boolean;
    "Arabic": boolean;
    "Armenian": boolean;
    "Avestan": boolean;
    "Balinese": boolean;
    "Bamum": boolean;
    "Bassa_Vah": boolean;
    "Batak": boolean;
    "Bengali": boolean;
    "Bhaiksuki": boolean;
    "Bopomofo": boolean;
    "Brahmi": boolean;
    "Braille": boolean;
    "Buginese": boolean;
    "Buhid": boolean;
    "Canadian_Aboriginal": boolean;
    "Carian": boolean;
    "Caucasian_Albanian": boolean;
    "Chakma": boolean;
    "Cham": boolean;
    "Cherokee": boolean;
    "Common": boolean;
    "Coptic": boolean;
    "Cuneiform": boolean;
    "Cypriot": boolean;
    "Cyrillic": boolean;
    "Deseret": boolean;
    "Devanagari": boolean;
    "Duployan": boolean;
    "Egyptian_Hieroglyphs": boolean;
    "Elbasan": boolean;
    "Ethiopic": boolean;
    "Georgian": boolean;
    "Glagolitic": boolean;
    "Gothic": boolean;
    "Grantha": boolean;
    "Greek": boolean;
    "Gujarati": boolean;
    "Gurmukhi": boolean;
    "Han": boolean;
    "Hangul": boolean;
    "Hanunoo": boolean;
    "Hatran": boolean;
    "Hebrew": boolean;
    "Hiragana": boolean;
    "Imperial_Aramaic": boolean;
    "Inherited": boolean;
    "Inscriptional_Pahlavi": boolean;
    "Inscriptional_Parthian": boolean;
    "Javanese": boolean;
    "Kaithi": boolean;
    "Kannada": boolean;
    "Katakana": boolean;
    "Kayah_Li": boolean;
    "Kharoshthi": boolean;
    "Khmer": boolean;
    "Khojki": boolean;
    "Khudawadi": boolean;
    "Lao": boolean;
    "Latin": boolean;
    "Lepcha": boolean;
    "Limbu": boolean;
    "Linear_A": boolean;
    "Linear_B": boolean;
    "Lisu": boolean;
    "Lycian": boolean;
    "Lydian": boolean;
    "Mahajani": boolean;
    "Malayalam": boolean;
    "Mandaic": boolean;
    "Manichaean": boolean;
    "Marchen": boolean;
    "Masaram_Gondi": boolean;
    "Meetei_Mayek": boolean;
    "Mende_Kikakui": boolean;
    "Meroitic_Cursive": boolean;
    "Meroitic_Hieroglyphs": boolean;
    "Miao": boolean;
    "Modi": boolean;
    "Mongolian": boolean;
    "Mro": boolean;
    "Multani": boolean;
    "Myanmar": boolean;
    "Nabataean": boolean;
    "New_Tai_Lue": boolean;
    "Newa": boolean;
    "Nko": boolean;
    "Nushu": boolean;
    "Ogham": boolean;
    "Ol_Chiki": boolean;
    "Old_Hungarian": boolean;
    "Old_Italic": boolean;
    "Old_North_Arabian": boolean;
    "Old_Permic": boolean;
    "Old_Persian": boolean;
    "Old_South_Arabian": boolean;
    "Old_Turkic": boolean;
    "Oriya": boolean;
    "Osage": boolean;
    "Osmanya": boolean;
    "Pahawh_Hmong": boolean;
    "Palmyrene": boolean;
    "Pau_Cin_Hau": boolean;
    "Phags_Pa": boolean;
    "Phoenician": boolean;
    "Psalter_Pahlavi": boolean;
    "Rejang": boolean;
    "Runic": boolean;
    "Samaritan": boolean;
    "Saurashtra": boolean;
    "Sharada": boolean;
    "Shavian": boolean;
    "Siddham": boolean;
    "SignWriting": boolean;
    "Sinhala": boolean;
    "Sora_Sompeng": boolean;
    "Soyombo": boolean;
    "Sundanese": boolean;
    "Syloti_Nagri": boolean;
    "Syriac": boolean;
    "Tagalog": boolean;
    "Tagbanwa": boolean;
    "Tai_Le": boolean;
    "Tai_Tham": boolean;
    "Tai_Viet": boolean;
    "Takri": boolean;
    "Tamil": boolean;
    "Tangut": boolean;
    "Telugu": boolean;
    "Thaana": boolean;
    "Thai": boolean;
    "Tibetan": boolean;
    "Tifinagh": boolean;
    "Tirhuta": boolean;
    "Ugaritic": boolean;
    "Vai": boolean;
    "Warang_Citi": boolean;
    "Yi": boolean;
    "Zanabazar_Square": boolean;
};
export declare const PatternTest: {
    [k in keyof typeof UNICODE_SCRIPTS_ALL]?: IPatternTestRow[];
};
export declare const testUnicodeScript: {
    (name: string, RegExpClass?: RegExpConstructor, testPatterns?: {
        "Adlam"?: IPatternTestRow[];
        "Ahom"?: IPatternTestRow[];
        "Anatolian_Hieroglyphs"?: IPatternTestRow[];
        "Arabic"?: IPatternTestRow[];
        "Armenian"?: IPatternTestRow[];
        "Avestan"?: IPatternTestRow[];
        "Balinese"?: IPatternTestRow[];
        "Bamum"?: IPatternTestRow[];
        "Bassa_Vah"?: IPatternTestRow[];
        "Batak"?: IPatternTestRow[];
        "Bengali"?: IPatternTestRow[];
        "Bhaiksuki"?: IPatternTestRow[];
        "Bopomofo"?: IPatternTestRow[];
        "Brahmi"?: IPatternTestRow[];
        "Braille"?: IPatternTestRow[];
        "Buginese"?: IPatternTestRow[];
        "Buhid"?: IPatternTestRow[];
        "Canadian_Aboriginal"?: IPatternTestRow[];
        "Carian"?: IPatternTestRow[];
        "Caucasian_Albanian"?: IPatternTestRow[];
        "Chakma"?: IPatternTestRow[];
        "Cham"?: IPatternTestRow[];
        "Cherokee"?: IPatternTestRow[];
        "Common"?: IPatternTestRow[];
        "Coptic"?: IPatternTestRow[];
        "Cuneiform"?: IPatternTestRow[];
        "Cypriot"?: IPatternTestRow[];
        "Cyrillic"?: IPatternTestRow[];
        "Deseret"?: IPatternTestRow[];
        "Devanagari"?: IPatternTestRow[];
        "Duployan"?: IPatternTestRow[];
        "Egyptian_Hieroglyphs"?: IPatternTestRow[];
        "Elbasan"?: IPatternTestRow[];
        "Ethiopic"?: IPatternTestRow[];
        "Georgian"?: IPatternTestRow[];
        "Glagolitic"?: IPatternTestRow[];
        "Gothic"?: IPatternTestRow[];
        "Grantha"?: IPatternTestRow[];
        "Greek"?: IPatternTestRow[];
        "Gujarati"?: IPatternTestRow[];
        "Gurmukhi"?: IPatternTestRow[];
        "Han"?: IPatternTestRow[];
        "Hangul"?: IPatternTestRow[];
        "Hanunoo"?: IPatternTestRow[];
        "Hatran"?: IPatternTestRow[];
        "Hebrew"?: IPatternTestRow[];
        "Hiragana"?: IPatternTestRow[];
        "Imperial_Aramaic"?: IPatternTestRow[];
        "Inherited"?: IPatternTestRow[];
        "Inscriptional_Pahlavi"?: IPatternTestRow[];
        "Inscriptional_Parthian"?: IPatternTestRow[];
        "Javanese"?: IPatternTestRow[];
        "Kaithi"?: IPatternTestRow[];
        "Kannada"?: IPatternTestRow[];
        "Katakana"?: IPatternTestRow[];
        "Kayah_Li"?: IPatternTestRow[];
        "Kharoshthi"?: IPatternTestRow[];
        "Khmer"?: IPatternTestRow[];
        "Khojki"?: IPatternTestRow[];
        "Khudawadi"?: IPatternTestRow[];
        "Lao"?: IPatternTestRow[];
        "Latin"?: IPatternTestRow[];
        "Lepcha"?: IPatternTestRow[];
        "Limbu"?: IPatternTestRow[];
        "Linear_A"?: IPatternTestRow[];
        "Linear_B"?: IPatternTestRow[];
        "Lisu"?: IPatternTestRow[];
        "Lycian"?: IPatternTestRow[];
        "Lydian"?: IPatternTestRow[];
        "Mahajani"?: IPatternTestRow[];
        "Malayalam"?: IPatternTestRow[];
        "Mandaic"?: IPatternTestRow[];
        "Manichaean"?: IPatternTestRow[];
        "Marchen"?: IPatternTestRow[];
        "Masaram_Gondi"?: IPatternTestRow[];
        "Meetei_Mayek"?: IPatternTestRow[];
        "Mende_Kikakui"?: IPatternTestRow[];
        "Meroitic_Cursive"?: IPatternTestRow[];
        "Meroitic_Hieroglyphs"?: IPatternTestRow[];
        "Miao"?: IPatternTestRow[];
        "Modi"?: IPatternTestRow[];
        "Mongolian"?: IPatternTestRow[];
        "Mro"?: IPatternTestRow[];
        "Multani"?: IPatternTestRow[];
        "Myanmar"?: IPatternTestRow[];
        "Nabataean"?: IPatternTestRow[];
        "New_Tai_Lue"?: IPatternTestRow[];
        "Newa"?: IPatternTestRow[];
        "Nko"?: IPatternTestRow[];
        "Nushu"?: IPatternTestRow[];
        "Ogham"?: IPatternTestRow[];
        "Ol_Chiki"?: IPatternTestRow[];
        "Old_Hungarian"?: IPatternTestRow[];
        "Old_Italic"?: IPatternTestRow[];
        "Old_North_Arabian"?: IPatternTestRow[];
        "Old_Permic"?: IPatternTestRow[];
        "Old_Persian"?: IPatternTestRow[];
        "Old_South_Arabian"?: IPatternTestRow[];
        "Old_Turkic"?: IPatternTestRow[];
        "Oriya"?: IPatternTestRow[];
        "Osage"?: IPatternTestRow[];
        "Osmanya"?: IPatternTestRow[];
        "Pahawh_Hmong"?: IPatternTestRow[];
        "Palmyrene"?: IPatternTestRow[];
        "Pau_Cin_Hau"?: IPatternTestRow[];
        "Phags_Pa"?: IPatternTestRow[];
        "Phoenician"?: IPatternTestRow[];
        "Psalter_Pahlavi"?: IPatternTestRow[];
        "Rejang"?: IPatternTestRow[];
        "Runic"?: IPatternTestRow[];
        "Samaritan"?: IPatternTestRow[];
        "Saurashtra"?: IPatternTestRow[];
        "Sharada"?: IPatternTestRow[];
        "Shavian"?: IPatternTestRow[];
        "Siddham"?: IPatternTestRow[];
        "SignWriting"?: IPatternTestRow[];
        "Sinhala"?: IPatternTestRow[];
        "Sora_Sompeng"?: IPatternTestRow[];
        "Soyombo"?: IPatternTestRow[];
        "Sundanese"?: IPatternTestRow[];
        "Syloti_Nagri"?: IPatternTestRow[];
        "Syriac"?: IPatternTestRow[];
        "Tagalog"?: IPatternTestRow[];
        "Tagbanwa"?: IPatternTestRow[];
        "Tai_Le"?: IPatternTestRow[];
        "Tai_Tham"?: IPatternTestRow[];
        "Tai_Viet"?: IPatternTestRow[];
        "Takri"?: IPatternTestRow[];
        "Tamil"?: IPatternTestRow[];
        "Tangut"?: IPatternTestRow[];
        "Telugu"?: IPatternTestRow[];
        "Thaana"?: IPatternTestRow[];
        "Thai"?: IPatternTestRow[];
        "Tibetan"?: IPatternTestRow[];
        "Tifinagh"?: IPatternTestRow[];
        "Tirhuta"?: IPatternTestRow[];
        "Ugaritic"?: IPatternTestRow[];
        "Vai"?: IPatternTestRow[];
        "Warang_Citi"?: IPatternTestRow[];
        "Yi"?: IPatternTestRow[];
        "Zanabazar_Square"?: IPatternTestRow[];
    }): boolean;
    (name: string, RegExpClass?: ICreateRegExp, testPatterns?: {
        "Adlam"?: IPatternTestRow[];
        "Ahom"?: IPatternTestRow[];
        "Anatolian_Hieroglyphs"?: IPatternTestRow[];
        "Arabic"?: IPatternTestRow[];
        "Armenian"?: IPatternTestRow[];
        "Avestan"?: IPatternTestRow[];
        "Balinese"?: IPatternTestRow[];
        "Bamum"?: IPatternTestRow[];
        "Bassa_Vah"?: IPatternTestRow[];
        "Batak"?: IPatternTestRow[];
        "Bengali"?: IPatternTestRow[];
        "Bhaiksuki"?: IPatternTestRow[];
        "Bopomofo"?: IPatternTestRow[];
        "Brahmi"?: IPatternTestRow[];
        "Braille"?: IPatternTestRow[];
        "Buginese"?: IPatternTestRow[];
        "Buhid"?: IPatternTestRow[];
        "Canadian_Aboriginal"?: IPatternTestRow[];
        "Carian"?: IPatternTestRow[];
        "Caucasian_Albanian"?: IPatternTestRow[];
        "Chakma"?: IPatternTestRow[];
        "Cham"?: IPatternTestRow[];
        "Cherokee"?: IPatternTestRow[];
        "Common"?: IPatternTestRow[];
        "Coptic"?: IPatternTestRow[];
        "Cuneiform"?: IPatternTestRow[];
        "Cypriot"?: IPatternTestRow[];
        "Cyrillic"?: IPatternTestRow[];
        "Deseret"?: IPatternTestRow[];
        "Devanagari"?: IPatternTestRow[];
        "Duployan"?: IPatternTestRow[];
        "Egyptian_Hieroglyphs"?: IPatternTestRow[];
        "Elbasan"?: IPatternTestRow[];
        "Ethiopic"?: IPatternTestRow[];
        "Georgian"?: IPatternTestRow[];
        "Glagolitic"?: IPatternTestRow[];
        "Gothic"?: IPatternTestRow[];
        "Grantha"?: IPatternTestRow[];
        "Greek"?: IPatternTestRow[];
        "Gujarati"?: IPatternTestRow[];
        "Gurmukhi"?: IPatternTestRow[];
        "Han"?: IPatternTestRow[];
        "Hangul"?: IPatternTestRow[];
        "Hanunoo"?: IPatternTestRow[];
        "Hatran"?: IPatternTestRow[];
        "Hebrew"?: IPatternTestRow[];
        "Hiragana"?: IPatternTestRow[];
        "Imperial_Aramaic"?: IPatternTestRow[];
        "Inherited"?: IPatternTestRow[];
        "Inscriptional_Pahlavi"?: IPatternTestRow[];
        "Inscriptional_Parthian"?: IPatternTestRow[];
        "Javanese"?: IPatternTestRow[];
        "Kaithi"?: IPatternTestRow[];
        "Kannada"?: IPatternTestRow[];
        "Katakana"?: IPatternTestRow[];
        "Kayah_Li"?: IPatternTestRow[];
        "Kharoshthi"?: IPatternTestRow[];
        "Khmer"?: IPatternTestRow[];
        "Khojki"?: IPatternTestRow[];
        "Khudawadi"?: IPatternTestRow[];
        "Lao"?: IPatternTestRow[];
        "Latin"?: IPatternTestRow[];
        "Lepcha"?: IPatternTestRow[];
        "Limbu"?: IPatternTestRow[];
        "Linear_A"?: IPatternTestRow[];
        "Linear_B"?: IPatternTestRow[];
        "Lisu"?: IPatternTestRow[];
        "Lycian"?: IPatternTestRow[];
        "Lydian"?: IPatternTestRow[];
        "Mahajani"?: IPatternTestRow[];
        "Malayalam"?: IPatternTestRow[];
        "Mandaic"?: IPatternTestRow[];
        "Manichaean"?: IPatternTestRow[];
        "Marchen"?: IPatternTestRow[];
        "Masaram_Gondi"?: IPatternTestRow[];
        "Meetei_Mayek"?: IPatternTestRow[];
        "Mende_Kikakui"?: IPatternTestRow[];
        "Meroitic_Cursive"?: IPatternTestRow[];
        "Meroitic_Hieroglyphs"?: IPatternTestRow[];
        "Miao"?: IPatternTestRow[];
        "Modi"?: IPatternTestRow[];
        "Mongolian"?: IPatternTestRow[];
        "Mro"?: IPatternTestRow[];
        "Multani"?: IPatternTestRow[];
        "Myanmar"?: IPatternTestRow[];
        "Nabataean"?: IPatternTestRow[];
        "New_Tai_Lue"?: IPatternTestRow[];
        "Newa"?: IPatternTestRow[];
        "Nko"?: IPatternTestRow[];
        "Nushu"?: IPatternTestRow[];
        "Ogham"?: IPatternTestRow[];
        "Ol_Chiki"?: IPatternTestRow[];
        "Old_Hungarian"?: IPatternTestRow[];
        "Old_Italic"?: IPatternTestRow[];
        "Old_North_Arabian"?: IPatternTestRow[];
        "Old_Permic"?: IPatternTestRow[];
        "Old_Persian"?: IPatternTestRow[];
        "Old_South_Arabian"?: IPatternTestRow[];
        "Old_Turkic"?: IPatternTestRow[];
        "Oriya"?: IPatternTestRow[];
        "Osage"?: IPatternTestRow[];
        "Osmanya"?: IPatternTestRow[];
        "Pahawh_Hmong"?: IPatternTestRow[];
        "Palmyrene"?: IPatternTestRow[];
        "Pau_Cin_Hau"?: IPatternTestRow[];
        "Phags_Pa"?: IPatternTestRow[];
        "Phoenician"?: IPatternTestRow[];
        "Psalter_Pahlavi"?: IPatternTestRow[];
        "Rejang"?: IPatternTestRow[];
        "Runic"?: IPatternTestRow[];
        "Samaritan"?: IPatternTestRow[];
        "Saurashtra"?: IPatternTestRow[];
        "Sharada"?: IPatternTestRow[];
        "Shavian"?: IPatternTestRow[];
        "Siddham"?: IPatternTestRow[];
        "SignWriting"?: IPatternTestRow[];
        "Sinhala"?: IPatternTestRow[];
        "Sora_Sompeng"?: IPatternTestRow[];
        "Soyombo"?: IPatternTestRow[];
        "Sundanese"?: IPatternTestRow[];
        "Syloti_Nagri"?: IPatternTestRow[];
        "Syriac"?: IPatternTestRow[];
        "Tagalog"?: IPatternTestRow[];
        "Tagbanwa"?: IPatternTestRow[];
        "Tai_Le"?: IPatternTestRow[];
        "Tai_Tham"?: IPatternTestRow[];
        "Tai_Viet"?: IPatternTestRow[];
        "Takri"?: IPatternTestRow[];
        "Tamil"?: IPatternTestRow[];
        "Tangut"?: IPatternTestRow[];
        "Telugu"?: IPatternTestRow[];
        "Thaana"?: IPatternTestRow[];
        "Thai"?: IPatternTestRow[];
        "Tibetan"?: IPatternTestRow[];
        "Tifinagh"?: IPatternTestRow[];
        "Tirhuta"?: IPatternTestRow[];
        "Ugaritic"?: IPatternTestRow[];
        "Vai"?: IPatternTestRow[];
        "Warang_Citi"?: IPatternTestRow[];
        "Yi"?: IPatternTestRow[];
        "Zanabazar_Square"?: IPatternTestRow[];
    }): boolean;
    <T>(name: string, RegExpClass?: ITypeCreateRegExp<T>, testPatterns?: {
        "Adlam"?: IPatternTestRow[];
        "Ahom"?: IPatternTestRow[];
        "Anatolian_Hieroglyphs"?: IPatternTestRow[];
        "Arabic"?: IPatternTestRow[];
        "Armenian"?: IPatternTestRow[];
        "Avestan"?: IPatternTestRow[];
        "Balinese"?: IPatternTestRow[];
        "Bamum"?: IPatternTestRow[];
        "Bassa_Vah"?: IPatternTestRow[];
        "Batak"?: IPatternTestRow[];
        "Bengali"?: IPatternTestRow[];
        "Bhaiksuki"?: IPatternTestRow[];
        "Bopomofo"?: IPatternTestRow[];
        "Brahmi"?: IPatternTestRow[];
        "Braille"?: IPatternTestRow[];
        "Buginese"?: IPatternTestRow[];
        "Buhid"?: IPatternTestRow[];
        "Canadian_Aboriginal"?: IPatternTestRow[];
        "Carian"?: IPatternTestRow[];
        "Caucasian_Albanian"?: IPatternTestRow[];
        "Chakma"?: IPatternTestRow[];
        "Cham"?: IPatternTestRow[];
        "Cherokee"?: IPatternTestRow[];
        "Common"?: IPatternTestRow[];
        "Coptic"?: IPatternTestRow[];
        "Cuneiform"?: IPatternTestRow[];
        "Cypriot"?: IPatternTestRow[];
        "Cyrillic"?: IPatternTestRow[];
        "Deseret"?: IPatternTestRow[];
        "Devanagari"?: IPatternTestRow[];
        "Duployan"?: IPatternTestRow[];
        "Egyptian_Hieroglyphs"?: IPatternTestRow[];
        "Elbasan"?: IPatternTestRow[];
        "Ethiopic"?: IPatternTestRow[];
        "Georgian"?: IPatternTestRow[];
        "Glagolitic"?: IPatternTestRow[];
        "Gothic"?: IPatternTestRow[];
        "Grantha"?: IPatternTestRow[];
        "Greek"?: IPatternTestRow[];
        "Gujarati"?: IPatternTestRow[];
        "Gurmukhi"?: IPatternTestRow[];
        "Han"?: IPatternTestRow[];
        "Hangul"?: IPatternTestRow[];
        "Hanunoo"?: IPatternTestRow[];
        "Hatran"?: IPatternTestRow[];
        "Hebrew"?: IPatternTestRow[];
        "Hiragana"?: IPatternTestRow[];
        "Imperial_Aramaic"?: IPatternTestRow[];
        "Inherited"?: IPatternTestRow[];
        "Inscriptional_Pahlavi"?: IPatternTestRow[];
        "Inscriptional_Parthian"?: IPatternTestRow[];
        "Javanese"?: IPatternTestRow[];
        "Kaithi"?: IPatternTestRow[];
        "Kannada"?: IPatternTestRow[];
        "Katakana"?: IPatternTestRow[];
        "Kayah_Li"?: IPatternTestRow[];
        "Kharoshthi"?: IPatternTestRow[];
        "Khmer"?: IPatternTestRow[];
        "Khojki"?: IPatternTestRow[];
        "Khudawadi"?: IPatternTestRow[];
        "Lao"?: IPatternTestRow[];
        "Latin"?: IPatternTestRow[];
        "Lepcha"?: IPatternTestRow[];
        "Limbu"?: IPatternTestRow[];
        "Linear_A"?: IPatternTestRow[];
        "Linear_B"?: IPatternTestRow[];
        "Lisu"?: IPatternTestRow[];
        "Lycian"?: IPatternTestRow[];
        "Lydian"?: IPatternTestRow[];
        "Mahajani"?: IPatternTestRow[];
        "Malayalam"?: IPatternTestRow[];
        "Mandaic"?: IPatternTestRow[];
        "Manichaean"?: IPatternTestRow[];
        "Marchen"?: IPatternTestRow[];
        "Masaram_Gondi"?: IPatternTestRow[];
        "Meetei_Mayek"?: IPatternTestRow[];
        "Mende_Kikakui"?: IPatternTestRow[];
        "Meroitic_Cursive"?: IPatternTestRow[];
        "Meroitic_Hieroglyphs"?: IPatternTestRow[];
        "Miao"?: IPatternTestRow[];
        "Modi"?: IPatternTestRow[];
        "Mongolian"?: IPatternTestRow[];
        "Mro"?: IPatternTestRow[];
        "Multani"?: IPatternTestRow[];
        "Myanmar"?: IPatternTestRow[];
        "Nabataean"?: IPatternTestRow[];
        "New_Tai_Lue"?: IPatternTestRow[];
        "Newa"?: IPatternTestRow[];
        "Nko"?: IPatternTestRow[];
        "Nushu"?: IPatternTestRow[];
        "Ogham"?: IPatternTestRow[];
        "Ol_Chiki"?: IPatternTestRow[];
        "Old_Hungarian"?: IPatternTestRow[];
        "Old_Italic"?: IPatternTestRow[];
        "Old_North_Arabian"?: IPatternTestRow[];
        "Old_Permic"?: IPatternTestRow[];
        "Old_Persian"?: IPatternTestRow[];
        "Old_South_Arabian"?: IPatternTestRow[];
        "Old_Turkic"?: IPatternTestRow[];
        "Oriya"?: IPatternTestRow[];
        "Osage"?: IPatternTestRow[];
        "Osmanya"?: IPatternTestRow[];
        "Pahawh_Hmong"?: IPatternTestRow[];
        "Palmyrene"?: IPatternTestRow[];
        "Pau_Cin_Hau"?: IPatternTestRow[];
        "Phags_Pa"?: IPatternTestRow[];
        "Phoenician"?: IPatternTestRow[];
        "Psalter_Pahlavi"?: IPatternTestRow[];
        "Rejang"?: IPatternTestRow[];
        "Runic"?: IPatternTestRow[];
        "Samaritan"?: IPatternTestRow[];
        "Saurashtra"?: IPatternTestRow[];
        "Sharada"?: IPatternTestRow[];
        "Shavian"?: IPatternTestRow[];
        "Siddham"?: IPatternTestRow[];
        "SignWriting"?: IPatternTestRow[];
        "Sinhala"?: IPatternTestRow[];
        "Sora_Sompeng"?: IPatternTestRow[];
        "Soyombo"?: IPatternTestRow[];
        "Sundanese"?: IPatternTestRow[];
        "Syloti_Nagri"?: IPatternTestRow[];
        "Syriac"?: IPatternTestRow[];
        "Tagalog"?: IPatternTestRow[];
        "Tagbanwa"?: IPatternTestRow[];
        "Tai_Le"?: IPatternTestRow[];
        "Tai_Tham"?: IPatternTestRow[];
        "Tai_Viet"?: IPatternTestRow[];
        "Takri"?: IPatternTestRow[];
        "Tamil"?: IPatternTestRow[];
        "Tangut"?: IPatternTestRow[];
        "Telugu"?: IPatternTestRow[];
        "Thaana"?: IPatternTestRow[];
        "Thai"?: IPatternTestRow[];
        "Tibetan"?: IPatternTestRow[];
        "Tifinagh"?: IPatternTestRow[];
        "Tirhuta"?: IPatternTestRow[];
        "Ugaritic"?: IPatternTestRow[];
        "Vai"?: IPatternTestRow[];
        "Warang_Citi"?: IPatternTestRow[];
        "Yi"?: IPatternTestRow[];
        "Zanabazar_Square"?: IPatternTestRow[];
    }): boolean;
};
export declare function testUnicodeScriptAll<T>(RegExpClass?: ITypeCreateRegExp<T>, testPatterns?: {
    "Adlam"?: IPatternTestRow[];
    "Ahom"?: IPatternTestRow[];
    "Anatolian_Hieroglyphs"?: IPatternTestRow[];
    "Arabic"?: IPatternTestRow[];
    "Armenian"?: IPatternTestRow[];
    "Avestan"?: IPatternTestRow[];
    "Balinese"?: IPatternTestRow[];
    "Bamum"?: IPatternTestRow[];
    "Bassa_Vah"?: IPatternTestRow[];
    "Batak"?: IPatternTestRow[];
    "Bengali"?: IPatternTestRow[];
    "Bhaiksuki"?: IPatternTestRow[];
    "Bopomofo"?: IPatternTestRow[];
    "Brahmi"?: IPatternTestRow[];
    "Braille"?: IPatternTestRow[];
    "Buginese"?: IPatternTestRow[];
    "Buhid"?: IPatternTestRow[];
    "Canadian_Aboriginal"?: IPatternTestRow[];
    "Carian"?: IPatternTestRow[];
    "Caucasian_Albanian"?: IPatternTestRow[];
    "Chakma"?: IPatternTestRow[];
    "Cham"?: IPatternTestRow[];
    "Cherokee"?: IPatternTestRow[];
    "Common"?: IPatternTestRow[];
    "Coptic"?: IPatternTestRow[];
    "Cuneiform"?: IPatternTestRow[];
    "Cypriot"?: IPatternTestRow[];
    "Cyrillic"?: IPatternTestRow[];
    "Deseret"?: IPatternTestRow[];
    "Devanagari"?: IPatternTestRow[];
    "Duployan"?: IPatternTestRow[];
    "Egyptian_Hieroglyphs"?: IPatternTestRow[];
    "Elbasan"?: IPatternTestRow[];
    "Ethiopic"?: IPatternTestRow[];
    "Georgian"?: IPatternTestRow[];
    "Glagolitic"?: IPatternTestRow[];
    "Gothic"?: IPatternTestRow[];
    "Grantha"?: IPatternTestRow[];
    "Greek"?: IPatternTestRow[];
    "Gujarati"?: IPatternTestRow[];
    "Gurmukhi"?: IPatternTestRow[];
    "Han"?: IPatternTestRow[];
    "Hangul"?: IPatternTestRow[];
    "Hanunoo"?: IPatternTestRow[];
    "Hatran"?: IPatternTestRow[];
    "Hebrew"?: IPatternTestRow[];
    "Hiragana"?: IPatternTestRow[];
    "Imperial_Aramaic"?: IPatternTestRow[];
    "Inherited"?: IPatternTestRow[];
    "Inscriptional_Pahlavi"?: IPatternTestRow[];
    "Inscriptional_Parthian"?: IPatternTestRow[];
    "Javanese"?: IPatternTestRow[];
    "Kaithi"?: IPatternTestRow[];
    "Kannada"?: IPatternTestRow[];
    "Katakana"?: IPatternTestRow[];
    "Kayah_Li"?: IPatternTestRow[];
    "Kharoshthi"?: IPatternTestRow[];
    "Khmer"?: IPatternTestRow[];
    "Khojki"?: IPatternTestRow[];
    "Khudawadi"?: IPatternTestRow[];
    "Lao"?: IPatternTestRow[];
    "Latin"?: IPatternTestRow[];
    "Lepcha"?: IPatternTestRow[];
    "Limbu"?: IPatternTestRow[];
    "Linear_A"?: IPatternTestRow[];
    "Linear_B"?: IPatternTestRow[];
    "Lisu"?: IPatternTestRow[];
    "Lycian"?: IPatternTestRow[];
    "Lydian"?: IPatternTestRow[];
    "Mahajani"?: IPatternTestRow[];
    "Malayalam"?: IPatternTestRow[];
    "Mandaic"?: IPatternTestRow[];
    "Manichaean"?: IPatternTestRow[];
    "Marchen"?: IPatternTestRow[];
    "Masaram_Gondi"?: IPatternTestRow[];
    "Meetei_Mayek"?: IPatternTestRow[];
    "Mende_Kikakui"?: IPatternTestRow[];
    "Meroitic_Cursive"?: IPatternTestRow[];
    "Meroitic_Hieroglyphs"?: IPatternTestRow[];
    "Miao"?: IPatternTestRow[];
    "Modi"?: IPatternTestRow[];
    "Mongolian"?: IPatternTestRow[];
    "Mro"?: IPatternTestRow[];
    "Multani"?: IPatternTestRow[];
    "Myanmar"?: IPatternTestRow[];
    "Nabataean"?: IPatternTestRow[];
    "New_Tai_Lue"?: IPatternTestRow[];
    "Newa"?: IPatternTestRow[];
    "Nko"?: IPatternTestRow[];
    "Nushu"?: IPatternTestRow[];
    "Ogham"?: IPatternTestRow[];
    "Ol_Chiki"?: IPatternTestRow[];
    "Old_Hungarian"?: IPatternTestRow[];
    "Old_Italic"?: IPatternTestRow[];
    "Old_North_Arabian"?: IPatternTestRow[];
    "Old_Permic"?: IPatternTestRow[];
    "Old_Persian"?: IPatternTestRow[];
    "Old_South_Arabian"?: IPatternTestRow[];
    "Old_Turkic"?: IPatternTestRow[];
    "Oriya"?: IPatternTestRow[];
    "Osage"?: IPatternTestRow[];
    "Osmanya"?: IPatternTestRow[];
    "Pahawh_Hmong"?: IPatternTestRow[];
    "Palmyrene"?: IPatternTestRow[];
    "Pau_Cin_Hau"?: IPatternTestRow[];
    "Phags_Pa"?: IPatternTestRow[];
    "Phoenician"?: IPatternTestRow[];
    "Psalter_Pahlavi"?: IPatternTestRow[];
    "Rejang"?: IPatternTestRow[];
    "Runic"?: IPatternTestRow[];
    "Samaritan"?: IPatternTestRow[];
    "Saurashtra"?: IPatternTestRow[];
    "Sharada"?: IPatternTestRow[];
    "Shavian"?: IPatternTestRow[];
    "Siddham"?: IPatternTestRow[];
    "SignWriting"?: IPatternTestRow[];
    "Sinhala"?: IPatternTestRow[];
    "Sora_Sompeng"?: IPatternTestRow[];
    "Soyombo"?: IPatternTestRow[];
    "Sundanese"?: IPatternTestRow[];
    "Syloti_Nagri"?: IPatternTestRow[];
    "Syriac"?: IPatternTestRow[];
    "Tagalog"?: IPatternTestRow[];
    "Tagbanwa"?: IPatternTestRow[];
    "Tai_Le"?: IPatternTestRow[];
    "Tai_Tham"?: IPatternTestRow[];
    "Tai_Viet"?: IPatternTestRow[];
    "Takri"?: IPatternTestRow[];
    "Tamil"?: IPatternTestRow[];
    "Tangut"?: IPatternTestRow[];
    "Telugu"?: IPatternTestRow[];
    "Thaana"?: IPatternTestRow[];
    "Thai"?: IPatternTestRow[];
    "Tibetan"?: IPatternTestRow[];
    "Tifinagh"?: IPatternTestRow[];
    "Tirhuta"?: IPatternTestRow[];
    "Ugaritic"?: IPatternTestRow[];
    "Vai"?: IPatternTestRow[];
    "Warang_Citi"?: IPatternTestRow[];
    "Yi"?: IPatternTestRow[];
    "Zanabazar_Square"?: IPatternTestRow[];
}): {
    "Adlam": boolean;
    "Ahom": boolean;
    "Anatolian_Hieroglyphs": boolean;
    "Arabic": boolean;
    "Armenian": boolean;
    "Avestan": boolean;
    "Balinese": boolean;
    "Bamum": boolean;
    "Bassa_Vah": boolean;
    "Batak": boolean;
    "Bengali": boolean;
    "Bhaiksuki": boolean;
    "Bopomofo": boolean;
    "Brahmi": boolean;
    "Braille": boolean;
    "Buginese": boolean;
    "Buhid": boolean;
    "Canadian_Aboriginal": boolean;
    "Carian": boolean;
    "Caucasian_Albanian": boolean;
    "Chakma": boolean;
    "Cham": boolean;
    "Cherokee": boolean;
    "Common": boolean;
    "Coptic": boolean;
    "Cuneiform": boolean;
    "Cypriot": boolean;
    "Cyrillic": boolean;
    "Deseret": boolean;
    "Devanagari": boolean;
    "Duployan": boolean;
    "Egyptian_Hieroglyphs": boolean;
    "Elbasan": boolean;
    "Ethiopic": boolean;
    "Georgian": boolean;
    "Glagolitic": boolean;
    "Gothic": boolean;
    "Grantha": boolean;
    "Greek": boolean;
    "Gujarati": boolean;
    "Gurmukhi": boolean;
    "Han": boolean;
    "Hangul": boolean;
    "Hanunoo": boolean;
    "Hatran": boolean;
    "Hebrew": boolean;
    "Hiragana": boolean;
    "Imperial_Aramaic": boolean;
    "Inherited": boolean;
    "Inscriptional_Pahlavi": boolean;
    "Inscriptional_Parthian": boolean;
    "Javanese": boolean;
    "Kaithi": boolean;
    "Kannada": boolean;
    "Katakana": boolean;
    "Kayah_Li": boolean;
    "Kharoshthi": boolean;
    "Khmer": boolean;
    "Khojki": boolean;
    "Khudawadi": boolean;
    "Lao": boolean;
    "Latin": boolean;
    "Lepcha": boolean;
    "Limbu": boolean;
    "Linear_A": boolean;
    "Linear_B": boolean;
    "Lisu": boolean;
    "Lycian": boolean;
    "Lydian": boolean;
    "Mahajani": boolean;
    "Malayalam": boolean;
    "Mandaic": boolean;
    "Manichaean": boolean;
    "Marchen": boolean;
    "Masaram_Gondi": boolean;
    "Meetei_Mayek": boolean;
    "Mende_Kikakui": boolean;
    "Meroitic_Cursive": boolean;
    "Meroitic_Hieroglyphs": boolean;
    "Miao": boolean;
    "Modi": boolean;
    "Mongolian": boolean;
    "Mro": boolean;
    "Multani": boolean;
    "Myanmar": boolean;
    "Nabataean": boolean;
    "New_Tai_Lue": boolean;
    "Newa": boolean;
    "Nko": boolean;
    "Nushu": boolean;
    "Ogham": boolean;
    "Ol_Chiki": boolean;
    "Old_Hungarian": boolean;
    "Old_Italic": boolean;
    "Old_North_Arabian": boolean;
    "Old_Permic": boolean;
    "Old_Persian": boolean;
    "Old_South_Arabian": boolean;
    "Old_Turkic": boolean;
    "Oriya": boolean;
    "Osage": boolean;
    "Osmanya": boolean;
    "Pahawh_Hmong": boolean;
    "Palmyrene": boolean;
    "Pau_Cin_Hau": boolean;
    "Phags_Pa": boolean;
    "Phoenician": boolean;
    "Psalter_Pahlavi": boolean;
    "Rejang": boolean;
    "Runic": boolean;
    "Samaritan": boolean;
    "Saurashtra": boolean;
    "Sharada": boolean;
    "Shavian": boolean;
    "Siddham": boolean;
    "SignWriting": boolean;
    "Sinhala": boolean;
    "Sora_Sompeng": boolean;
    "Soyombo": boolean;
    "Sundanese": boolean;
    "Syloti_Nagri": boolean;
    "Syriac": boolean;
    "Tagalog": boolean;
    "Tagbanwa": boolean;
    "Tai_Le": boolean;
    "Tai_Tham": boolean;
    "Tai_Viet": boolean;
    "Takri": boolean;
    "Tamil": boolean;
    "Tangut": boolean;
    "Telugu": boolean;
    "Thaana": boolean;
    "Thai": boolean;
    "Tibetan": boolean;
    "Tifinagh": boolean;
    "Tirhuta": boolean;
    "Ugaritic": boolean;
    "Vai": boolean;
    "Warang_Citi": boolean;
    "Yi": boolean;
    "Zanabazar_Square": boolean;
};
export declare function wrapToRegexName(name: string, negation?: boolean): string;
import * as self from './unicode-script';
export default self;
